"""
********************************************************************************
compas_mobile_robot_reloc
********************************************************************************
"""
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from os import path

import compas
import compas.plugins

from .three_pts_localization import *  # noqa: F401, F403

if not compas.RHINO:
    from .arbitrary_pts_localization import *  # noqa: F401, F403

PKG_ROOT = path.dirname(__file__)
REPO_ROOT = path.abspath(path.join(PKG_ROOT, ".."))

compas.PRECISION = "12f"


def _get_version():  # type: () -> str
    # from https://smarie.github.io/python-getversion/#package-versioning-best-practices
    # and setuptools_scm docs
    try:
        # import from _version.py generated by setuptools_scm during release
        from ._version import version

        return version
    except ImportError:
        try:
            from importlib.metadata import PackageNotFoundError
            from importlib.metadata import version  # type: ignore [no-redef]
        except ImportError:
            # fmt: off
            from importlib_metadata import (PackageNotFoundError)  # type: ignore [no-redef]  # noqa: E501
            # fmt: on
            from importlib_metadata import version  # type: ignore [no-redef]

        try:
            return version("rapid-clay-formations-fab")  # type: ignore [operator]

        except PackageNotFoundError:
            # package is not installed
            pass

    return "src"


@compas.plugins.plugin(category="install")
def installable_rhino_packages():
    return ["compas_mobile_robot_reloc"]


__author__ = "Gramazio Kohler Research"
__copyright__ = "2020 Gramazio Kohler Research"
__license__ = "MIT License"
__email__ = "anton@tetov.se"
__version__ = _get_version()


__all_plugins__ = ["compas_mobile_robot_reloc.rhino_install"]
